documentationtools.GraphvizObject
=================================

.. abjad-lineage:: abjad.tools.documentationtools.GraphvizObject.GraphvizObject.GraphvizObject

.. autoclass:: abjad.tools.documentationtools.GraphvizObject.GraphvizObject.GraphvizObject
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.documentationtools.GraphvizObject.GraphvizObject.GraphvizObject.attributes
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizObject.GraphvizObject.GraphvizObject.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.documentationtools.GraphvizObject.GraphvizObject.GraphvizObject.__eq__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizObject.GraphvizObject.GraphvizObject.__ge__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizObject.GraphvizObject.GraphvizObject.__gt__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizObject.GraphvizObject.GraphvizObject.__le__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizObject.GraphvizObject.GraphvizObject.__lt__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizObject.GraphvizObject.GraphvizObject.__ne__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizObject.GraphvizObject.GraphvizObject.__repr__
   :noindex:
